pages = [
    "Home" => "index.md",
    "Getting Started" => "getting_started.md",
    "Tutorials" => [
        "User Guide" => "tutorials/user_tutorial.md",
        "Developer Guide" => "tutorials/developer_tutorial.md",
    ],
    "Manual" => [
        "Message Levels" => "manual/message_levels.md",
        "Verbosity Specifiers" => "manual/verbosity_specifiers.md",
        "Verbosity Presets" => "manual/presets.md",
        "@SciMLMessage Macro" => "manual/macro.md",
        "Conversion Utilities" => "manual/conversion_utilities.md",
        "Logging Backends" => "manual/backends.md",
    ],
]
